import { defineConfig, UserConfigExport } from 'vite'
import vue from '@vitejs/plugin-vue'
import path from 'path'
import WindiCss from 'vite-plugin-windicss';
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers'
import ConditionalCompile from './plugins/vite-plugin-conditional-compile'

// https://vitejs.dev/config/
export default defineConfig(({ command }) => {

  const config: UserConfigExport = {
    // base:'/app/xdjx/',
    // base: '/app/xdjy/',
    // base: '/app/xdhq/',
    resolve: {
      alias: {
        '~': `${path.resolve(__dirname, 'src')}`,
        '~/': `${path.resolve(__dirname, 'src/')}`,
        '~components': `${path.resolve(__dirname, 'src/components')}`,
        '@': `${path.resolve(__dirname, 'src')}`,
      },
    },
    css: {
      preprocessorOptions: {
        scss: {
          additionalData: `@use "~/styles/element/index.scss" as *;`,
        },
      },
    },
    plugins: [
      ConditionalCompile(),
      vue(),
      WindiCss(),
      AutoImport({
        resolvers: [ElementPlusResolver()],
      }),
      Components({
        resolvers: [ElementPlusResolver()],
      }),
    ],
    build: {
      // target: 'modules'
      target: 'esnext',
      rollupOptions: {
        output: {
          manualChunks: {
            lodash: ['lodash-es'],
            echarts: ['echarts'],
            axios: ['axios']
          }
        }
      }
    },

  }

  switch (command as string) {
    case 'build:xdhq':
      config.base = '/app/xdhq/'
      break;
    case 'build:xdjy':
      config.base = '/app/xdjy/'
      break;
    case 'build:xdjx':
      config.base = '/app/xdjx/'
      break;
    case 'serve':
      config.base = '/'
      break;
  }

  console.log('config.base :>> ', config.base);
  // console.log('config.env :>> ', config.env);
  return config
}


)
